pub enum GetBlocksError {
    BadFirstBlockIndex {
        requested_index: BlockIndex,
        first_valid_index: BlockIndex,
    },
    Other {
        error_code: u64,
        error_message: String,
    },
}
An error indicating that the arguments passed to get_blocks or query_archived_blocks were invalid.

Variants



BadFirstBlockIndex

Fields

requested_index: BlockIndex

The index that was requested.

first_valid_index: BlockIndex

The minimum index that can be requested, for this particular call.

The GetBlocksArgs.start argument was smaller than the first block served by the canister that received the request.



Other

Fields

error_code: u64

A machine-readable error code.

error_message: String

A human-readable error message.

Reserved for future use.