pub enum Operation {
    Mint {
        to: AccountIdentifier,
        amount: Tokens,
    },
    Burn {
        from: AccountIdentifier,
        amount: Tokens,
    },
    Transfer {
        from: AccountIdentifier,
        to: AccountIdentifier,
        amount: Tokens,
        fee: Tokens,
    },
    Approve {
        from: AccountIdentifier,
        spender: AccountIdentifier,
        expires_at: Option<Timestamp>,
        fee: Tokens,
    },
    TransferFrom {
        from: AccountIdentifier,
        to: AccountIdentifier,
        spender: AccountIdentifier,
        amount: Tokens,
        fee: Tokens,
    },
}
The content of a ledger transaction.

Variants



Mint

Fields

to: AccountIdentifier

The account that the tokens were transferred to.

amount: Tokens

The amount that was transferred.

Tokens were minted, usually via spawning/disbursing neuron maturity or as node operator rewards.



Burn

Fields

from: AccountIdentifier

The account that sent the tokens to be burned.

amount: Tokens

The amount that was burned.

Tokens were burned, usually to create cycles for a canister.



Transfer

Fields

from: AccountIdentifier

The account the tokens were transferred from.

to: AccountIdentifier

The account the tokens were transferred to.

amount: Tokens

The amount of tokens that were transferred.

fee: Tokens

The fee that was charged for the transfer.

Tokens were transferred from one account to another.



Approve

Fields

from: AccountIdentifier

The account that owns the tokens.

spender: AccountIdentifier

The account that was enabled to spend them.

expires_at: Option<Timestamp>

The expiration date for this approval.

fee: Tokens

The fee that was charged for the approval.

An account approved another account to transfer tokens on its behalf.



TransferFrom

Fields

from: AccountIdentifier

The account that the tokens were transferred from.

to: AccountIdentifier

The account that the tokens were transferred to.

spender: AccountIdentifier

The account that performed the transfer.

amount: Tokens

The amount that was transferred.

fee: Tokens

The fee that was charged for the transfer.

An account transferred tokens from another account on its behalf, following an approval.