Type Definition ic_ledger_types::BlockIndex
source · pub type BlockIndex = u64;Expand description
The sequence number of a block in the Tokens ledger blockchain.
pub type BlockIndex = u64;The sequence number of a block in the Tokens ledger blockchain.