Enum ic_ledger_types::Operation
source · pub enum Operation {
Mint {
to: AccountIdentifier,
amount: Tokens,
},
Burn {
from: AccountIdentifier,
amount: Tokens,
},
Transfer {
from: AccountIdentifier,
to: AccountIdentifier,
amount: Tokens,
fee: Tokens,
},
Approve {
from: AccountIdentifier,
spender: AccountIdentifier,
expires_at: Option<Timestamp>,
fee: Tokens,
},
TransferFrom {
from: AccountIdentifier,
to: AccountIdentifier,
spender: AccountIdentifier,
amount: Tokens,
fee: Tokens,
},
}Expand description
The content of a ledger transaction.
Variants
Mint
Fields
to: AccountIdentifierThe account that the tokens were transferred to.
Tokens were minted, usually via spawning/disbursing neuron maturity or as node operator rewards.
Burn
Fields
from: AccountIdentifierThe account that sent the tokens to be burned.
Tokens were burned, usually to create cycles for a canister.
Transfer
Fields
from: AccountIdentifierThe account the tokens were transferred from.
to: AccountIdentifierThe account the tokens were transferred to.
Tokens were transferred from one account to another.
Approve
Fields
from: AccountIdentifierThe account that owns the tokens.
spender: AccountIdentifierThe account that was enabled to spend them.
An account approved another account to transfer tokens on its behalf.
TransferFrom
Fields
from: AccountIdentifierThe account that the tokens were transferred from.
to: AccountIdentifierThe account that the tokens were transferred to.
spender: AccountIdentifierThe account that performed the transfer.
An account transferred tokens from another account on its behalf, following an approval.